Summary

- Original orientation: LAS
- Repetition time (TR): 1.6s
- Phase-encoding (PE) direction: Left-Right
- Multi-echo EPI sequence: 4 echoes.
- Slice timing correction: Applied
- Susceptibility distortion correction: None
- Registration: FreeSurfer `bbregister` (boundary-based registration, BBR) - 6 dof
- Non-steady-state volumes: 1

Confounds collected

global_signal, global_signal_derivative1, global_signal_power2, global_signal_derivative1_power2, csf, csf_derivative1, csf_power2, csf_derivative1_power2, white_matter, white_matter_derivative1, white_matter_power2, white_matter_derivative1_power2, csf_wm, tcompcor, std_dvars, dvars, framewise_displacement, rmsd, t_comp_cor_00, t_comp_cor_01, t_comp_cor_02, t_comp_cor_03, t_comp_cor_04, c_comp_cor_00, c_comp_cor_01, c_comp_cor_02, c_comp_cor_03, c_comp_cor_04, c_comp_cor_05, c_comp_cor_06, c_comp_cor_07, c_comp_cor_08, c_comp_cor_09, c_comp_cor_10, c_comp_cor_11, c_comp_cor_12, c_comp_cor_13, c_comp_cor_14, c_comp_cor_15, c_comp_cor_16, c_comp_cor_17, c_comp_cor_18, c_comp_cor_19, c_comp_cor_20, c_comp_cor_21, c_comp_cor_22, c_comp_cor_23, c_comp_cor_24, w_comp_cor_00, w_comp_cor_01, w_comp_cor_02, w_comp_cor_03, w_comp_cor_04, w_comp_cor_05, w_comp_cor_06, w_comp_cor_07, w_comp_cor_08, w_comp_cor_09, w_comp_cor_10, w_comp_cor_11, w_comp_cor_12, w_comp_cor_13, w_comp_cor_14, w_comp_cor_15, w_comp_cor_16, w_comp_cor_17, w_comp_cor_18, w_comp_cor_19, w_comp_cor_20, w_comp_cor_21, w_comp_cor_22, w_comp_cor_23, w_comp_cor_24, w_comp_cor_25, w_comp_cor_26, w_comp_cor_27, w_comp_cor_28, w_comp_cor_29, w_comp_cor_30, w_comp_cor_31, w_comp_cor_32, w_comp_cor_33, w_comp_cor_34, w_comp_cor_35, w_comp_cor_36, w_comp_cor_37, w_comp_cor_38, w_comp_cor_39, w_comp_cor_40, w_comp_cor_41, w_comp_cor_42, a_comp_cor_00, a_comp_cor_01, a_comp_cor_02, a_comp_cor_03, a_comp_cor_04, a_comp_cor_05, a_comp_cor_06, a_comp_cor_07, a_comp_cor_08, a_comp_cor_09, a_comp_cor_10, a_comp_cor_11, a_comp_cor_12, a_comp_cor_13, a_comp_cor_14, a_comp_cor_15, a_comp_cor_16, a_comp_cor_17, a_comp_cor_18, a_comp_cor_19, a_comp_cor_20, a_comp_cor_21, a_comp_cor_22, a_comp_cor_23, a_comp_cor_24, a_comp_cor_25, a_comp_cor_26, a_comp_cor_27, a_comp_cor_28, a_comp_cor_29, a_comp_cor_30, a_comp_cor_31, a_comp_cor_32, a_comp_cor_33, a_comp_cor_34, a_comp_cor_35, a_comp_cor_36, a_comp_cor_37, a_comp_cor_38, a_comp_cor_39, a_comp_cor_40, a_comp_cor_41, edge_comp_00, edge_comp_01, edge_comp_02, edge_comp_03, edge_comp_04, edge_comp_05, edge_comp_06, edge_comp_07, edge_comp_08, edge_comp_09, edge_comp_10, edge_comp_11, edge_comp_12, edge_comp_13, edge_comp_14, edge_comp_15, edge_comp_16, edge_comp_17, edge_comp_18, edge_comp_19, edge_comp_20, edge_comp_21, edge_comp_22, edge_comp_23, cosine00, non_steady_state_outlier00, trans_x, trans_x_derivative1, trans_x_derivative1_power2, trans_x_power2, trans_y, trans_y_derivative1, trans_y_power2, trans_y_derivative1_power2, trans_z, trans_z_derivative1, trans_z_power2, trans_z_derivative1_power2, rot_x, rot_x_derivative1, rot_x_derivative1_power2, rot_x_power2, rot_y, rot_y_derivative1, rot_y_power2, rot_y_derivative1_power2, rot_z, rot_z_derivative1, rot_z_power2, rot_z_derivative1_power2.